==> process-decisions-rest-springboot-1.16.1.Final-sources.jar: org/kie/kogito/traffic/Rules267FC1B65547FE8E6DE7B65BC34612BE.java <==
package org.kie.kogito.traffic;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;

public abstract class Rules267FC1B65547FE8E6DE7B65BC34612BE implements org.drools.model.Model {

    public final static java.time.format.DateTimeFormatter DATE_TIME_FORMATTER = new java.time.format.DateTimeFormatterBuilder().parseCaseInsensitive().appendPattern(org.drools.core.util.DateUtils.getDateFormatMask()).toFormatter(java.util.Locale.ENGLISH);

    @Override
    public String getName() {
        return "org.kie.kogito.traffic";
    }

    @Override
    public java.util.List<org.drools.model.EntryPoint> getEntryPoints() {
        return java.util.Arrays.asList(D.entryPoint("driver"));
    }

    @Override
    public java.util.List<org.drools.model.Global> getGlobals() {
        return globals;
    }

    @Override
    public java.util.List<org.drools.model.TypeMetaData> getTypeMetaDatas() {
        return typeMetaDatas;
    }

    public static final org.drools.model.Global<java.util.Date> var_currentTime = D.globalOf(java.util.Date.class,
                                                                                             "org.kie.kogito.traffic",
                                                                                             "currentTime");

    public static final org.drools.model.Global<org.kie.kogito.rules.SingletonStore> var_driver = D.globalOf(org.kie.kogito.rules.SingletonStore.class,
                                                                                                             "org.kie.kogito.traffic",
                                                                                                             "driver");

    public static final org.drools.model.Query0Def queryDef_validation = D.query("org.kie.kogito.traffic",
                                                                                 "validation");

    java.util.List<org.drools.model.Global> globals = new java.util.ArrayList<>();

    java.util.List<org.drools.model.TypeMetaData> typeMetaDatas = java.util.Collections.emptyList();

    {
        globals.add(var_currentTime);
        globals.add(var_driver);
    }
}

==> process-decisions-rest-springboot-1.21.0.Final-sources.jar: org/kie/kogito/traffic/Rules267FC1B65547FE8E6DE7B65BC34612BE.java <==
package org.kie.kogito.traffic;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;

public abstract class Rules267FC1B65547FE8E6DE7B65BC34612BE implements org.drools.model.Model {

    public final static java.time.format.DateTimeFormatter DATE_TIME_FORMATTER = new java.time.format.DateTimeFormatterBuilder().parseCaseInsensitive().appendPattern(org.drools.util.DateUtils.getDateFormatMask()).toFormatter(java.util.Locale.ENGLISH);

    @Override
    public String getName() {
        return "org.kie.kogito.traffic";
    }

    @Override
    public java.util.List<org.drools.model.EntryPoint> getEntryPoints() {
        return java.util.Arrays.asList(D.entryPoint("driver"));
    }

    @Override
    public java.util.List<org.drools.model.Global> getGlobals() {
        return globals;
    }

    @Override
    public java.util.List<org.drools.model.TypeMetaData> getTypeMetaDatas() {
        return typeMetaDatas;
    }

    public static final org.drools.model.Global<java.util.Date> var_currentTime = D.globalOf(java.util.Date.class,
                                                                                             "org.kie.kogito.traffic",
                                                                                             "currentTime");

    public static final org.drools.model.Global<org.kie.kogito.rules.SingletonStore> var_driver = D.globalOf(org.kie.kogito.rules.SingletonStore.class,
                                                                                                             "org.kie.kogito.traffic",
                                                                                                             "driver");

    public static final org.drools.model.Query0Def queryDef_validation = D.query("org.kie.kogito.traffic",
                                                                                 "validation");

    java.util.List<org.drools.model.Global> globals = new java.util.ArrayList<>();

    java.util.List<org.drools.model.TypeMetaData> typeMetaDatas = java.util.Collections.emptyList();

    {
        globals.add(var_currentTime);
        globals.add(var_driver);
    }
}
